==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Modify/Rotate2/ts/Rotate2_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja_JP">
<context>
    <name>Rotate2</name>
    <message>
        <location filename="../Rotate2.js" line="+67"/>
        <source>Center of primary rotation</source>
        <translation>主要な回転の中心</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Center of secondary rotation</source>
        <translation>２つ目の回転の中心</translation>
    </message>
    <message>
        <location filename="../Rotate2Init.js" line="+2"/>
        <source>Rotate T&amp;wo</source>
        <translation>&amp;w 回転２</translation>
    </message>
    <message>
        <location filename="../Rotate2.ui" line="+17"/>
        <source>Primary Angle:</source>
        <translation type="unfinished">主要な角度:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Secondary Angle:</source>
        <translation type="unfinished">２つ目の角度:</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Copies:</source>
        <translation type="unfinished">コピー:</translation>
    </message>
</context>
<context>
    <name>Rotate2Options</name>
    <message>
        <location filename="../Rotate2Dialog.ui" line="+14"/>
        <source>Rotate Two Options</source>
        <translation>回転２オプション</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Number of Copies</source>
        <translation>コピーの数</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>&amp;Delete original</source>
        <translation>&amp;D オリジナルを削除</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>&amp;Keep original</source>
        <translation>&amp;K オリジナルを維持</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>&amp;Multiple copies</source>
        <translation>&amp;M 多重コピー</translation>
    </message>
    <message>
        <location line="+94"/>
        <source>Angle (&amp;a):</source>
        <translation>角度(&amp;a):</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Angle (&amp;b):</source>
        <translation>角度(&amp;b):</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>Use current layer and &amp;attributes</source>
        <translation>&amp;a 現在の画層と属性を利用</translation>
    </message>
</context>
<context>
    <name>TranslateRotate</name>
    <message>
        <source>Primary Angle:</source>
        <translation type="vanished">主要な角度:</translation>
    </message>
    <message>
        <source>Secondary Angle:</source>
        <translation type="vanished">２つ目の角度:</translation>
    </message>
    <message>
        <source>Copies:</source>
        <translation type="vanished">コピー:</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Modify/Rotate2/ts/Rotate2_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>Rotate2</name>
    <message>
        <location filename="../Rotate2.js" line="+67"/>
        <source>Center of primary rotation</source>
        <translation>主要な回転の中心</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Center of secondary rotation</source>
        <translation>２つ目の回転の中心</translation>
    </message>
    <message>
        <location filename="../Rotate2Init.js" line="+2"/>
        <source>Rotate T&amp;wo</source>
        <translation>&amp;w 回転２</translation>
    </message>
    <message>
        <location filename="../Rotate2.ui" line="+17"/>
        <source>Primary Angle:</source>
        <translation>１つ目の角度:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Secondary Angle:</source>
        <translation>２つ目の角度:</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Copies:</source>
        <translation>コピー数:</translation>
    </message>
</context>
<context>
    <name>Rotate2Options</name>
    <message>
        <location filename="../Rotate2Dialog.ui" line="+14"/>
        <source>Rotate Two Options</source>
        <translation>回転２オプション</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Number of Copies</source>
        <translation>コピーの数</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>&amp;Delete original</source>
        <translation>&amp;D オリジナルを削除</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>&amp;Keep original</source>
        <translation>&amp;K オリジナルを維持</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>&amp;Multiple copies</source>
        <translation>&amp;M 多重コピー</translation>
    </message>
    <message>
        <location line="+94"/>
        <source>Angle (&amp;a):</source>
        <translation>角度(&amp;a):</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Angle (&amp;b):</source>
        <translation>角度(&amp;b):</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>Use current layer and &amp;attributes</source>
        <translation>&amp;a 現在の画層と属性を利用</translation>
    </message>
</context>
<context>
    <name>TranslateRotate</name>
    <message>
        <source>Primary Angle:</source>
        <translation type="vanished">主要な角度:</translation>
    </message>
    <message>
        <source>Secondary Angle:</source>
        <translation type="vanished">２つ目の角度:</translation>
    </message>
    <message>
        <source>Copies:</source>
        <translation type="vanished">コピー:</translation>
    </message>
</context>
</TS>
